@@ -13,16 +13,16 @@
 
 #include "eckit/config/LocalConfiguration.h"
 #include "eckit/parser/JSONParser.h"
+#include "eckit/serialisation/Stream.h"
 #include "eckit/types/Types.h"
 #include "eckit/utils/Tokenizer.h"
 #include "eckit/value/Value.h"
-#include "eckit/serialisation/Stream.h"
 
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-LocalConfiguration::LocalConfiguration(char separator) : Configuration(Value::makeMap(), separator) {}
+LocalConfiguration::LocalConfiguration(char separator) : Configuration(Value::makeOrderedMap(), separator) {}
 
 LocalConfiguration::LocalConfiguration(Stream& s) : Configuration(Value(s)) {}
 
@@ -56,7 +56,7 @@ void LocalConfiguration::setValue(const std::vector<std::string>& path, size_t i
 
     if (!root.contains(path[i])) {
         // std::cout << i << " NEW " << path[i]  << std::endl;
-        root[path[i]] = eckit::Value::makeMap();
+        root[path[i]] = eckit::Value::makeOrderedMap();
     }
 
     eckit::Value& r = root.element(path[i]);
