@@ -18,6 +18,7 @@
 #include <sys/statvfs.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <utime.h>
 
 #include <cstring>  // for strlen
 #include <deque>
@@ -28,6 +29,7 @@
 #include "eckit/config/Resource.h"
 #include "eckit/filesystem/BasePathNameT.h"
 #include "eckit/filesystem/PathNameFactory.h"
+#include "eckit/filesystem/StdDir.h"
 #include "eckit/io/FileHandle.h"
 #include "eckit/io/Length.h"
 #include "eckit/io/PartFileHandle.h"
@@ -147,7 +149,12 @@ LocalPathName LocalPathName::baseName(bool ext) const {
         if (n >= 0)
             s.resize(n);
     }
-    return s;
+
+    // Don't perform tilde expansion on paths that have already been expanded
+
+    bool tildeIsUserHome = false;
+    bool skipTildeExpansion = true;
+    return LocalPathName(s, tildeIsUserHome, skipTildeExpansion);
 }
 
 std::string LocalPathName::extension() const {
@@ -188,7 +195,7 @@ BasePathName* LocalPathName::checkClusterNode() const {
     std::string n = ClusterDisks::node(path_);
     if (n != "local") {
         //        Log::warning() << *this << " is now on node [" << n << "]" << std::endl;
-        return PathNameFactory::instance().build(std::string("marsfs://") + n + path_);
+        return PathNameFactory::build(std::string("marsfs://") + n + path_);
     }
     return new BasePathNameT<LocalPathName>(LocalPathName(path_));
 }
@@ -492,11 +499,13 @@ static void rebuild_path(const std::vector<std::string>& v, std::string& path, b
     }
 }
 
-LocalPathName& LocalPathName::tidy(bool tildeIsUserHome) {
+LocalPathName& LocalPathName::tidy(bool tildeIsUserHome, bool skipTildeExpansion) {
     if (path_.length() == 0)
         return *this;
 
-    expandTilde(path_, tildeIsUserHome);
+    if (!skipTildeExpansion) {
+        expandTilde(path_, tildeIsUserHome);
+    }
 
     bool trail = (path_[path_.length() - 1] == '/');  // remember to put back ending '/' if there is one
 
@@ -511,19 +520,7 @@ LocalPathName& LocalPathName::tidy(bool tildeIsUserHome) {
     return *this;
 }
 
-class StdDir {
-    DIR* d_;
-
-public:
-    StdDir(const LocalPathName& p) { d_ = opendir(p.localPath()); }
-    ~StdDir() {
-        if (d_)
-            closedir(d_);
-    }
-    operator DIR*() { return d_; }
-};
-
-void LocalPathName::match(const LocalPathName& root, std::vector<LocalPathName>& result, bool rec) {
+void LocalPathName::match(const LocalPathName& root, std::vector<LocalPathName>& result, bool recursive) {
     // Note that pattern matching will only be done
     // on the base name.
 
@@ -546,41 +543,24 @@ void LocalPathName::match(const LocalPathName& root, std::vector<LocalPathName>&
         throw FailedSystemCall(std::string("opendir(") + std::string(dir) + ")");
     }
 
-    struct dirent buf;
-
-
     for (;;) {
-        struct dirent* e;
-#ifdef eckit_HAVE_READDIR_R
-        errno = 0;
-        if (readdir_r(d, &buf, &e) != 0) {
-            if (errno)
-                throw FailedSystemCall("readdir_r");
-            else
-                e = 0;
-        }
-#else
-        e = readdir(d);
-#endif
-
-        if (e == 0)
+        struct dirent* e = d.dirent();
+        if (e == nullptr)
             break;
 
         //        Log::info() << "e->d_name = " << e->d_name << std::endl;
 
         if (re.match(e->d_name)) {
             //            Log::info() << "match !!! ---> " << e->d_name << std::endl;
-
             LocalPathName path = std::string(dir) + std::string("/") + std::string(e->d_name);
             result.push_back(path);
         }
 
-        if (rec && e->d_name[0] != '.') {
+        if (recursive && e->d_name[0] != '.') {
             LocalPathName full = dir + "/" + e->d_name;
-            Stat::Struct info;
-            SYSCALL(Stat::lstat(full.c_str(), &info));
-            if (S_ISDIR(info.st_mode))
+            if(full.isDir()) {
                 match(full + "/" + base, result, true);
+            }
         }
     }
 }
@@ -641,25 +621,11 @@ void LocalPathName::children(std::vector<LocalPathName>& files, std::vector<Loca
         throw FailedSystemCall("opendir");
     }
 
-    struct dirent buf;
-
-
     for (;;) {
-        struct dirent* e;
-#ifdef eckit_HAVE_READDIR_R
-        errno = 0;
-        if (readdir_r(d, &buf, &e) != 0) {
-            if (errno)
-                throw FailedSystemCall("readdir_r");
-            else
-                e = 0;
+        struct dirent* e = d.dirent();
+        if (e == nullptr) {
+                break;
         }
-#else
-        e = readdir(d);
-#endif
-
-        if (e == 0)
-            break;
 
         if (e->d_name[0] == '.')
             if (e->d_name[1] == 0 || (e->d_name[1] == '.' && e->d_name[2] == 0))
@@ -699,7 +665,13 @@ void LocalPathName::children(std::vector<LocalPathName>& files, std::vector<Loca
 
 void LocalPathName::touch() const {
     dirName().mkdir();
-    AutoStdFile f(*this, "a");  // This should touch the file
+
+    if(exists()) {
+        SYSCALL(::utime(path_.c_str(), nullptr)); // set to current time
+    }
+    else {
+        AutoStdFile f(*this, "a");  // this creates the file, ther may be a race but is unimportant in this context
+    }
 }
 
 // This method is used by TxnLog. It is important that
