@@ -13,7 +13,6 @@
 #include "eckit/exception/Exceptions.h"
 #include "eckit/filesystem/TmpFile.h"
 
-
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -24,12 +23,12 @@ static PathName tmp() {
         tmpdir = "/tmp";
     }
 
-    long max = pathconf(tmpdir, _PC_PATH_MAX);
+    long max   = pathconf(tmpdir, _PC_PATH_MAX);
     char* path = new char[max];
 
     sprintf(path, "%s/eckitXXXXXXXXXXX", tmpdir);
     int fd;
-    SYSCALL(fd = ::mkstemp(path));
+    SYSCALL2(fd = ::mkstemp(path), path);
 
     PathName result(path);
     result.touch();
