@@ -32,28 +32,41 @@ URI::URI(const std::string& uri) {
     if (!uri.empty()) {
         size_t first = parseScheme(uri);
         if (URIManager::exists(scheme_)) {
-            URIManager &um = URIManager::lookUp(scheme_);
+            URIManager& um = URIManager::lookUp(scheme_);
             parse(uri, first, um.authority(), um.query(), um.fragment());
-        } else {
+        }
+        else {
             scheme_ = "unix";
-            name_ = uri;
+            name_   = uri;
         }
     }
 }
 
-URI::URI(const std::string& scheme, const PathName& path):
-    scheme_(scheme), name_(path.path()) {}
+URI::URI(const std::string& scheme, const PathName& path) :
+    name_(path.path()), scheme_(scheme), user_(""), host_(""), port_(-1), fragment_(""), queryValues_({}) {}
 
-URI::URI(const std::string &scheme, const URI &uri):
-    scheme_(scheme), user_(uri.user_), host_(uri.host_), port_(uri.port_), name_(uri.name_), fragment_(uri.fragment_), queryValues_(uri.queryValues_) {}
+URI::URI(const std::string& scheme, const URI& uri) :
+    name_(uri.name_),
+    scheme_(scheme),
+    user_(uri.user_),
+    host_(uri.host_),
+    port_(uri.port_),
+    fragment_(uri.fragment_),
+    queryValues_(uri.queryValues_) {}
 
-URI::URI(const std::string &scheme, const std::string &hostname, const int port):
-    scheme_(scheme), host_(hostname), port_(port) {}
+URI::URI(const std::string& scheme, const std::string& hostname, const int port) :
+    name_(""), scheme_(scheme), user_(""), host_(hostname), port_(port), fragment_(""), queryValues_({}) {}
 
-URI::URI(const std::string &scheme, const URI &uri, const std::string &hostname, const int port):
-    scheme_(scheme), user_(uri.user_), host_(hostname), port_(port), name_(uri.name_), fragment_(uri.fragment_), queryValues_(uri.queryValues_) {}
+URI::URI(const std::string& scheme, const URI& uri, const std::string& hostname, const int port) :
+    name_(uri.name_),
+    scheme_(scheme),
+    user_(uri.user_),
+    host_(hostname),
+    port_(port),
+    fragment_(uri.fragment_),
+    queryValues_(uri.queryValues_) {}
 
-URI::URI(Stream &s) {
+URI::URI(Stream& s) {
     s >> scheme_;
     s >> user_;
     s >> host_;
@@ -71,9 +84,10 @@ bool URI::operator<(const URI& other) const {
 
 size_t URI::parseScheme(const std::string& uri) {
     std::size_t schemeEnd = uri.find(":");
-    if (schemeEnd >= 0 && schemeEnd != std::string::npos) {
+    if (schemeEnd != std::string::npos) {
         std::string schemeLowercase = StringTools::lower(uri.substr(0, schemeEnd));
-        std::size_t acceptableProtocolEnd = schemeLowercase.find_first_not_of("abcdefghijklmnopqrstuvwxyz0123456789+-.");
+        std::size_t acceptableProtocolEnd =
+            schemeLowercase.find_first_not_of("abcdefghijklmnopqrstuvwxyz0123456789+-.");
         if (acceptableProtocolEnd == std::string::npos) {
             scheme_ = schemeEnd == 0 ? "unix" : uri.substr(0, schemeEnd);
             return schemeEnd + 1;
@@ -86,7 +100,7 @@ size_t URI::parseScheme(const std::string& uri) {
 void URI::parse(const std::string& str, size_t first, bool authority, bool query, bool fragment) {
     size_t last = str.length();
 
-    if (fragment) { // get fragment start
+    if (fragment) {  // get fragment start
         std::size_t fragmentStart = str.find_last_of("#");
         if (fragmentStart != std::string::npos) {
             fragment_ = str.substr(fragmentStart + 1);
@@ -95,11 +109,11 @@ void URI::parse(const std::string& str, size_t first, bool authority, bool query
         }
     }
 
-    if (query) { // get query start
+    if (query) {  // get query start
         std::size_t queryStart = str.find_last_of("?", last);
         if (queryStart != std::string::npos) {
             std::string query = str.substr(queryStart + 1, last - queryStart - 1);
-            last = queryStart;
+            last              = queryStart;
 
             if (!query.empty())
                 parseQueryValues(query);
@@ -126,8 +140,9 @@ void URI::parse(const std::string& str, size_t first, bool authority, bool query
                     port_ = port_ * 10 + (str[i] - '0');
                 }
                 first = i;
-            } else {
-                port_ = -1;
+            }
+            else {
+                port_               = -1;
                 std::size_t hostEnd = str.find("/", first);
                 if (hostEnd == std::string::npos) {
                     hostEnd = last;
@@ -138,17 +153,17 @@ void URI::parse(const std::string& str, size_t first, bool authority, bool query
         }
     }
 
-    name_ = str.substr(first, last-first);
+    name_ = str.substr(first, last - first);
 }
 
-void URI::parseQueryValues(const std::string &query) {
+void URI::parseQueryValues(const std::string& query) {
 
     Tokenizer parse("&");
     Tokenizer splitValues("=");
     std::vector<std::string> attributeValuePairs;
 
     parse(query, attributeValuePairs);
-    for (std::string &attributeValue : attributeValuePairs) {
+    for (std::string& attributeValue : attributeValuePairs) {
         std::vector<std::string> s;
         splitValues(attributeValue, s);
         if (s.size() == 2) {
@@ -181,16 +196,22 @@ DataHandle* URI::newReadHandle() const {
     return URIManager::lookUp(scheme_).newReadHandle(*this);
 }
 
-std::string URI::authority() const {
-    std::string authority;
-    if (!user_.empty())
-        authority = user_ + "@";
-    if (!host_.empty())
-        authority += host_;
-    if (port_ != -1)
-        authority += ":" + (port_>0 ? std::to_string(port_) : "");
+std::string URI::hostport() const {
+    if (host_.empty() || port_ < 0)
+        return host_;
 
-    return authority;
+    if (port_ == 0)
+        return host_ + ":";
+
+    return host_ + ":" + std::to_string(port_);
+}
+
+std::string URI::authority() const {
+    std::string host = hostport();
+    if (host.empty() || user_.empty())
+        return host;
+
+    return user_ + "@" + host;
 }
 
 void URI::query(const std::string& attribute, const std::string& value) {
@@ -206,7 +227,7 @@ const std::string URI::query(const std::string& attribute) const {
 
 std::string URI::query() const {
     std::string query;
-    for (auto &attributeValue : queryValues_) {
+    for (auto& attributeValue : queryValues_) {
         if (!query.empty())
             query += "&";
 
@@ -219,8 +240,13 @@ void URI::fragment(const std::string& fragment) {
     fragment_ = fragment;
 }
 
+PathName URI::path() const {
+    ASSERT(!scheme_.empty());
+    return URIManager::lookUp(scheme_).path(*this);
+}
+
 std::string URI::asString() const {
-//    ASSERT(!name_.empty());
+    //    ASSERT(!name_.empty());
     ASSERT(!scheme_.empty());
     return URIManager::lookUp(scheme_).asString(*this);
 }
@@ -228,21 +254,31 @@ std::string URI::asString() const {
 std::string URI::asRawString() const {
     std::string auth = authority();
     if (!auth.empty())
-        auth = "//"+auth;
+        auth = "//" + auth;
     std::string q = query();
     if (!q.empty())
-        q = "?"+q;
+        q = "?" + q;
 
-    return scheme_ + ":" + auth + name_ + q + (fragment_.empty() ? "" : "#"+fragment_);
+    return scheme_ + ":" + auth + name_ + q + (fragment_.empty() ? "" : "#" + fragment_);
 }
 
 void URI::print(std::ostream& s) const {
-    s << "URI[scheme=" << scheme_ << ",name=" << name_ << "]";
+    s << "URI[scheme=" << scheme_;
+    if (!user_.empty())
+        s << ",user=" << user_;
+    if (!host_.empty())
+        s << ",host=" << host_;
+    if (port_ != -1)
+        s << ",port=" << port_;
+    s << ",name=" << name_;
+    if (!fragment_.empty())
+        s << ",fragment=" << fragment_;
+    if (!queryValues_.empty())
+        s << ",query=" << queryValues_;
+    s << "]";
 }
 
-void URI::encode(Stream &s) const {
-    std::cout << "URI " << asRawString() << " - start encoding\n";
-
+void URI::encode(Stream& s) const {
     s << scheme_;
     s << user_;
     s << host_;
@@ -250,8 +286,6 @@ void URI::encode(Stream &s) const {
     s << name_;
     s << fragment_;
     s << queryValues_;
-
-    std::cout << "URI " << asRawString() << " encoded\n";
 }
 
 //----------------------------------------------------------------------------------------------------------------------
