@@ -36,6 +36,8 @@ public:
     virtual long write(const void*, long) override;
     virtual void close() override;
     virtual void print(std::ostream&) const override;
+    virtual Offset seek(const Offset&) override;
+    virtual bool canSeek() const override { return true; }
 
     virtual void encode(Stream&) const override;
 
