@@ -199,6 +199,16 @@ CASE("Test comparisons using OrderedMap") {
     }
 }
 
+CASE("Check order is preserved when cloning") {
+    Value om1 = Value::makeOrderedMap();
+    om1["c"] = 1;
+    om1["b"] = 2;
+    om1["a"] = 3;
+    Value om2 = om1.clone();
+    EXPECT(om2.compare(om1) == 0);  // Keys are equal and inserted in same order
+    EXPECT(om1.compare(om2) == 0);  // Keys are equal and inserted in same order
+}
+
 CASE("Check comparisons with other types of data.") {
     Value om1          = Value::makeOrderedMap();
     om1[123]           = 1234;
@@ -465,20 +475,33 @@ CASE("Test head/tail functionality for OrderedMap") {
 }
 
 CASE("Hash of a value") {
-    std::unique_ptr<Hash> h(make_hash());
 
-    Value om  = Value::makeOrderedMap();
-    om[123]   = 1234;
-    om[234]   = 2345;
-    om[777]   = 7777;
-    om["abc"] = "def";
-    om[true]  = false;
+    auto create = [](Value& m) {
+      m[123]   = 1234;
+      m[234]   = 2345;
+      m[777]   = 7777;
+      m["abc"] = "def";
+      m[true]  = false;
+    };
 
-    om.hash(*h);
+    auto hash = [](Value& m) -> std::string {
+      std::unique_ptr<Hash> h(make_hash());
+      m.hash(*h);
+      return h->digest();
+    };
 
-    //    std::cout << "MD5 " << h->digest() << std::endl;
+    Value orderedMap  = Value::makeOrderedMap();
+    Value sortedMap   = Value::makeMap();
+    create(orderedMap);
+    create(sortedMap);
+    std::string orderedHash = hash(orderedMap);
+    std::string sortedHash  = hash(sortedMap);
 
-    EXPECT(h->digest() == "d88d5bd6eb0a9d56d9132e0aca7f903f");
+    // std::cout << "MD5 ordered " << orderedHash << std::endl;
+    // std::cout << "MD5 sorted  " << sortedHash << std::endl;
+
+    EXPECT( orderedHash == sortedHash );
+    EXPECT( orderedHash == "4259b7e50da09908c9fba2584b71db79" );
 }
 
 //----------------------------------------------------------------------------------------------------------------------
